#!/usr/bin/env python

from sqlalchemy import Column, Integer, String, DateTime
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()


class Account(Base):
    __tablename__ = "accounts"
    full_name = Column(String(255))
    inactive = Column(String(1))
    preferred_email = Column(String(255))
    registered_on = Column(DateTime)
    account_id = Column(Integer, primary_key=True)

    def __repr__(self):
        return "{}, {}, {}, {}, {}".format(
            self.full_name,
            self.inactive,
            self.preferred_email,
            self.registered_on,
            self.account_id
        )


class Group(Base):
    __tablename__ = "account_groups"
    group_uuid = Column(String(255))
    name = Column(String(255))
    group_id = Column(Integer, primary_key=True)

    def __repr__(self):
        return "{}, {}, {}".format(
            self.group_uuid,
            self.name,
            self.group_id,
        )


class Account_External_Ids(Base):
    __tablename__ = 'account_external_ids'
    account_id = Column(String(255))
    email_address = Column(String(255))
    external_id = Column(String(255), primary_key=True)

    def __repr__(self):
        return "{}, {}, {}".format(
            self.account_id,
            self.email_address,
            self.external_id,
        )


class Account_Ssh_Keys(Base):
    __tablename__ = 'account_ssh_keys'
    account_id = Column(Integer, primary_key=True)
    ssh_public_key = Column(String)

    def __repr__(self):
        return "{}, {}".format(
            self.account_id,
            self.ssh_public_key,
        )


class Account_Group_Members(Base):
    __tablename__ = 'account_group_members'
    account_id = Column(Integer, primary_key=True)
    group_id = Column(Integer, primary_key=True)

    def __repr__(self):
        return "{}, {}".format(
            self.account_id,
            self.group_id,
        )
